@@ -26,11 +26,6 @@
 #include <QSqlError>
 #include "privmsg.h"
 #include "contentencryptionmodel.h"
-#ifdef WIN32
-#include <QJson/Parser>
-#else
-#include <qjson/parser.h>
-#endif
 #include "const.h"
 
 PrivMessageModel::PrivMessageModel(MController *aController,
@@ -186,6 +181,10 @@ PrivMessage* PrivMessageModel::messageByFingerPrint(const Hash& aFingerPrint) {
                     plainTextPrivMessageData ) ) {
                 LOG_STR2("message: %s", qPrintable(QString(plainTextPrivMessageData)));
                 ret = retval->fromJSon(plainTextPrivMessageData,*iController) ;
+            } else {
+                delete retval ;
+                retval = NULL ;
+                ret = false ; 
             }
 
             if ( ret )  {
@@ -549,3 +548,4 @@ void PrivMessageModel::setAsRead(const Hash& aMessageHash, bool aIsRead ) {
         emit error(MController::DbTransactionError, query.lastError().text()) ;
     }
 }
+
